@@ -27,24 +27,16 @@ class ClimatizationStatus(GenericStatus):
         LOG.debug('Update Climatization status from dict')
 
         if 'value' in fromDict:
+            self.climatisationState.fromDict(fromDict['value'], 'climatisationState')
             if 'remainingClimatisationTime_min' in fromDict['value']:
-                self.remainingClimatisationTime_min.setValueWithCarTime(int(fromDict['value']['remainingClimatisationTime_min']),
-                                                                        lastUpdateFromCar=None, fromServer=True)
+                remainingTime = int(fromDict['value']['remainingClimatisationTime_min'])
+                if self.fixAPI and remainingTime != 0 and self.climatisationState.value == ClimatizationStatus.ClimatizationState.OFF:
+                    remainingTime = 0
+                    LOG.debug('%s: Attribute remainingClimatisationTime_min is %s while climatisationState is %s. Setting 0 instead',
+                              self.getGlobalAddress(), fromDict['value']['remainingClimatisationTime_min'], self.climatisationState.value)
+                self.remainingClimatisationTime_min.setValueWithCarTime(remainingTime, lastUpdateFromCar=None, fromServer=True)
             else:
                 self.remainingClimatisationTime_min.enabled = False
-
-            if 'climatisationState' in fromDict['value'] and fromDict['value']['climatisationState']:
-                try:
-                    self.climatisationState.setValueWithCarTime(
-                        ClimatizationStatus.ClimatizationState(fromDict['value']['climatisationState']), lastUpdateFromCar=None,
-                        fromServer=True)
-                except ValueError:
-                    self.climatisationState.setValueWithCarTime(ClimatizationStatus.ClimatizationState.UNKNOWN,
-                                                                lastUpdateFromCar=None, fromServer=True)
-                    LOG.warning('An unsupported climatisationState: %s was provided,'
-                                ' please report this as a bug', fromDict['value']['climatisationState'])
-            else:
-                self.climatisationState.enabled = False
         else:
             self.remainingClimatisationTime_min.enabled = False
             self.climatisationState.enabled = False
@@ -65,4 +57,5 @@ class ClimatizationStatus(GenericStatus):
         HEATING = 'heating'
         COOLING = 'cooling'
         VENTILATION = 'ventilation'
+        INVALID = 'invalid'
         UNKNOWN = 'unknown climatization state'
